<?php

namespace Slack\Blockkit\Blocks;

use Illuminate\Support\Collection;

use Slack\Blockkit\Blocks;
use Slack\Exceptions\SlackSyntaxException;

final class Context extends Blocks
{
	protected const LIMITS = [
		'block_id' => 255,			// @todo Should be unique for each message
	];

	private const MAX_ELEMENTS = 10;

	/**
	 * @param Collection $collection
	 * @throws SlackSyntaxException
	 * @todo Collection can only be image or text elements
	 */
	public function __construct(Collection $collection)
	{
		parent::__construct();

		// Defaults
		$this->type = 'context';

		if (count($collection) > self::MAX_ELEMENTS)
			throw new SlackSyntaxException(sprintf('Can only have maximum %d elements',self::MAX_ELEMENTS));

		$this->elements = $collection;
	}

	public static function item(Collection $collection): self
	{
		return new self($collection);
	}

	/* OPTIONAL ITEMS */

	public function block_id(string $string): self
	{
		$this->block_id = $this->validate('block_id',$string);

		return $this;
	}
}