<?php

namespace Slack\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;

use App\Http\Controllers\Controller;
use Slack\Client\Payload;
use Slack\Message;
use Slack\Interactive\Factory as InteractiveMessageFactory;

final class InteractiveMessageController extends Controller
{
	private const LOGKEY = 'CIM';

	/**
	 * Fire slack event
	 *
	 * @param Request $request
	 * @return \Illuminate\Http\Response|\Laravel\Lumen\Http\ResponseFactory
	 */
	public function fire(Request $request)
	{
		$event = InteractiveMessageFactory::make(new Payload(json_decode($request->payload,TRUE),TRUE));
		Log::debug(sprintf('%s:Firing Event [%s] and responding [%s]',static::LOGKEY,get_class($event),$event->respondNow));

		if ($event->respondNow) {
			if (! method_exists($event,'respond')) {
				Log::alert(sprintf('%s:Cant respond to Event [%s], no respond method',static::LOGKEY,get_class($event)));

			} else {
				$result = $event->respond();

				return (($result instanceof Message) AND $result->isEmpty()) ? NULL : $result;
			}

		} else {
			event($event);

			Log::info(sprintf('%s:Dispatched Event [%s]',static::LOGKEY,get_class($event)));
			return response('IM Event Processed',200);
		}
	}
}