<?php

namespace Slack\Jobs;

use Illuminate\Support\Facades\Log;

use Slack\Exceptions\SlackException;
use Slack\Message;

final class DeleteResponse extends Job
{
	private const LOGKEY = 'JDC';

	/**
	 * Create a new job instance.
	 *
	 * @param string $url
	 */
	public function __construct(string $url)
	{
		$this->_data['url'] = $url;
	}

	/**
	 * Execute the job.
	 *
	 * @return void
	 */
	public function handle()
	{
		Log::info(sprintf('%s:Start - Delete Response [%s]',static::LOGKEY,$this->url),['m'=>__METHOD__]);

		$o = new Message;
		$o->text('')
			->delete_original();

		try {
			$o->respond($this->url);

			Log::debug(sprintf('%s:Deleted Slack Message: %s',static::LOGKEY,$this->url),['m'=>__METHOD__]);

		} catch (SlackException $e) {
			Log::error(sprintf('%s:Failed to delete slack message [%s] [%s]',static::LOGKEY,$this->url,$e->getMessage()),['m'=>__METHOD__]);
		}
	}
}